/* irman-python -- A minimal set of Python bindings for libirman.
 * Copyright (C) 2002  Chris Houser <chouser@bluweb.com>
 * $Id: irmanmodule.c,v 1.4 2002/08/08 01:33:46 chouser Exp chouser $
 * http://bluweb.com/chouser/proj/irman-python/
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <Python.h>
#include <irman.h>

static PyObject *IrmanError;

static PyObject *
irman_init_commands(PyObject *self, PyObject *args)
{
    /* arg defaults */
    char *rcname = NULL;
    char warn = 1;

    /* parse args */
    if (!PyArg_ParseTuple(args, "|sb", &rcname, &warn))
        return NULL;

    /* call library command */
    if (ir_init_commands(rcname, warn) < 0) {
        PyErr_SetFromErrno(IrmanError);
    }

    /* return None */
    Py_INCREF(Py_None);
    return Py_None;
}

static PyObject *
irman_default_portname(PyObject *self, PyObject *args)
{
    /* return variable */
    char *portname;

    /* parse args */
    if (!PyArg_ParseTuple(args, ""))
        return NULL;

    /* call library command */
    portname = ir_default_portname();

    /* return it */
    return Py_BuildValue("s", portname);
}

static PyObject *
irman_init(PyObject *self, PyObject *args)
{
    /* args */
    char *filename;

    /* return variables */
    int portfd;

    /* parse args */
    if (!PyArg_ParseTuple(args, "s", &filename))
        return NULL;

    /* call library command */
    portfd = ir_init(filename);
    if (portfd < 0) {
        PyErr_SetFromErrno(IrmanError);
        return NULL;
    }

    /* return file descriptor */
    return Py_BuildValue("i", portfd);
}

static PyObject *
irman_get_text(PyObject *self, PyObject *args)
{
    /* return variables */
    unsigned char *code;
    char *text;

    /* parse args */
    if (!PyArg_ParseTuple(args, ""))
        return NULL;

    /* call library command */
    code = ir_get_code();
    if (code == NULL) {
        PyErr_SetFromErrno(IrmanError);
        return NULL;
    }

    /* convert code to text */
    text = ir_code_to_text(code);
    if (text == NULL) {
        PyErr_SetFromErrno(IrmanError);
        return NULL;
    }

    /* return it */
    return Py_BuildValue("s", text);
}

static PyObject *
irman_text_to_name(PyObject *self, PyObject *args)
{
    /* args */
    char *text;

    /* return variables */
    char *name;

    /* parse args */
    if (!PyArg_ParseTuple(args, "s", &text))
        return NULL;

    /* call library command */
    name = ir_text_to_name(text);
    if (name == NULL) {
        PyErr_SetFromErrno(IrmanError);
        return NULL;
    }

    /* return it */
    return Py_BuildValue("s", name);
}

static PyObject *
irman_finish(PyObject *self, PyObject *args)
{
    /* parse args */
    if (!PyArg_ParseTuple(args, ""))
        return NULL;

    /* call library command */
    if (ir_finish() < 0) {
        PyErr_SetFromErrno(IrmanError);
    }

    /* return None */
    Py_INCREF(Py_None);
    return Py_None;
}


static PyMethodDef IrmanMethods[] = {
    {"init_commands",    irman_init_commands,    METH_VARARGS},
    {"default_portname", irman_default_portname, METH_VARARGS},
    {"init",             irman_init,             METH_VARARGS},
    {"get_text",         irman_get_text,         METH_VARARGS},
    {"text_to_name",     irman_text_to_name,     METH_VARARGS},
    {"finish",           irman_finish,           METH_VARARGS},
    {NULL, NULL} /* End of Methods Sentinel */
};

void
initirman(void)
{
    PyObject *m, *d;

    m = Py_InitModule("irman", IrmanMethods);
    d = PyModule_GetDict(m);
    IrmanError = PyErr_NewException("irman.error", NULL, NULL);
    PyDict_SetItemString(d, "error", IrmanError);
}
